@@ -1,7 +1,5 @@
 #
-# Copyright 2013 Intel
-# Copyright 2013 Isaku Yamahata <isaku.yamahata at intel com>
-#                               <isaku.yamahata at gmail com>
+# Copyright 2013 Intel Corporation
 # All Rights Reserved.
 #
 #
@@ -24,21 +22,21 @@ _VNF = 'vnf'
 
 
 class ListVNF(tackerV10.ListCommand):
-    """List device that belong to a given tenant."""
+    """List VNF that belong to a given tenant."""
 
     resource = _VNF
     list_columns = ['id', 'name', 'description', 'mgmt_url', 'status',
-                    'vim_id', 'placement_attr']
+                    'vim_id', 'placement_attr', 'error_reason']
 
 
 class ShowVNF(tackerV10.ShowCommand):
-    """show information of a given VNF."""
+    """Show information of a given VNF."""
 
     resource = _VNF
 
 
 class CreateVNF(tackerV10.CreateCommand):
-    """create a VNF."""
+    """Create a VNF."""
 
     resource = _VNF
     remove_output_fields = ["attributes"]
@@ -46,7 +44,7 @@ class CreateVNF(tackerV10.CreateCommand):
     def add_known_arguments(self, parser):
         parser.add_argument(
             '--name',
-            help='Set a name for the vnf')
+            help='Set a name for the VNF')
         vnfd_group = parser.add_mutually_exclusive_group(required=True)
         vnfd_group.add_argument(
             '--vnfd-id',
@@ -66,13 +64,13 @@ class CreateVNF(tackerV10.CreateCommand):
             help='VIM Region to use to create VNF on the specified VIM')
         parser.add_argument(
             '--config-file',
-            help='specify config yaml file')
+            help='Specify config yaml file')
         parser.add_argument(
             '--config',
-            help='specify config yaml data')
+            help='Specify config yaml data')
         parser.add_argument(
             '--param-file',
-            help='specify parameter yaml file'
+            help='Specify parameter yaml file'
         )
 
     def args2body(self, parsed_args):
@@ -122,10 +120,10 @@ class UpdateVNF(tackerV10.UpdateCommand):
     def add_known_arguments(self, parser):
         parser.add_argument(
             '--config-file',
-            help='specify config yaml file')
+            help='Specify config yaml file')
         parser.add_argument(
             '--config',
-            help='specify config yaml data')
+            help='Specify config yaml data')
 
     def args2body(self, parsed_args):
         body = {self.resource: {}}
